@@ -53,15 +53,17 @@ Copyright 2011-2016 Los Alamos National Security, LLC.
    set_target
    shared_ylabel
    solarRotationPlot
-   spectrogram
+   Spectrogram
    style
    timestamp
+   add_arrows
 
 Most of the functionality in the plot module is made available directly 
 through the *plot* namespace. However, the plot module does contain
 several submodules listed below
 
 .. autosummary::
+    :toctree: autosummary
     :template: clean_module.rst
 
     carrington
@@ -75,6 +77,7 @@ try:
 except ImportError:
     from collections import Mapping
 import os
+import warnings
 import numpy as np
 import matplotlib as mpl
 from matplotlib.patches import Wedge
@@ -395,7 +398,7 @@ def levelPlot(data, var=None, time=None, levels=(3, 5), target=None, colors=None
         except (IndexError, KeyError):
             #using data array to index, so should just use time
             applySmartTimeTicks(ax, time)
-        ax.grid('off', which='minor') #minor grid usually looks bad on these...
+        ax.grid(False, which='minor') #minor grid usually looks bad on these...
 
     if legend:
         ncols = len(levels)+1
@@ -403,3 +406,16 @@ def levelPlot(data, var=None, time=None, levels=(3, 5), target=None, colors=None
         ax.legend(loc='upper left', ncol=ncols)
 
     return ax
+
+
+class spectrogram(Spectrogram):
+    """Deprecated variant of :class:`~spacepy.plot.Spectrogram`
+
+    .. deprecated: 0.2.2
+       Use :class:`~spacepy.plot.Spectrogram` instead.
+    """
+
+    def __init__(self, *args, **kwargs):
+        warnings.warn('Use spacepy.plot.Spectrogram (capitalized).',
+                      DeprecationWarning)
+        super(spectrogram, self).__init__(*args, **kwargs)
