@@ -322,10 +322,9 @@ class Sea(SeaBase):
         self.bound_high = np.zeros((m,1))
 
         if kwargs['quartiles']:
-            from matplotlib.mlab import prctile
             for i in range(m):
                 dum = np.sort(y_sea_m[:,i].compressed())
-                qul = prctile(dum,p=(25,75))
+                qul = np.percentile(dum, (25,75))
                 self.bound_low[i], self.bound_high[i] = qul[0], qul[1]
                 self.bound_type = 'quartiles'
         elif kwargs['ci']: #bootstrapped confidence intervals (95%)
@@ -440,10 +439,9 @@ class Sea(SeaBase):
         #outobj.bound_high = np.zeros((m,1))
 
         #if quartiles:
-            #from matplotlib.mlab import prctile
             #for i in range(m):
                 #dum = np.sort(y_sea_m[:,i].compressed())
-                #qul = prctile(dum,p=(25,75))
+                #qul = np.percentile(dum, (25,75))
                 #outobj.bound_low[i], outobj.bound_high[i] = qul[0], qul[1]
         #elif ci: #bootstrapped confidence intervals (95%)
             #from spacepy.poppy import boots_ci
@@ -528,7 +526,6 @@ class Sea(SeaBase):
         else:
             ax0.fill_between(self.x, self.bound_low.ravel(), self.bound_high.ravel(),
                              edgecolor='none', facecolor=color, interpolate=True)
-        plt.hold(True)
         ax0.plot(self.x, self.semedian, 'k-', lw=2.0)
         ax0.plot(self.x, self.semean, 'r--', lw=1.25)
         plt.xlabel(xlstr)
@@ -626,7 +623,7 @@ class Sea2d(SeaBase):
             nmask = 0 #set mask to exclude none
 
         #build SEA matrix and perform analysis
-        wind = self.window
+        wind = int(self.window)
         l = y.shape[0]
         m = 2*int(wind) + 1
         n = len(t_epoch)
@@ -1018,7 +1015,6 @@ def sea_signif(obj1, obj2, test='KS', show=True, xquan = 'Time Since Epoch',
     ax1 = fig.add_subplot(212, position=[pos.bounds[0], 0.1, pos.bounds[2], 0.25])
     #overlay superposed epochs
     ax0.plot(obj1.x, obj1.semedian, lw=1.5)
-    plt.hold(True)
     ax0.plot(obj1.x, obj1.bound_high, color='royalblue', ls='--')
     ax0.plot(obj1.x, obj1.bound_low, color='royalblue', ls='--')
     ax0.plot(obj2.x, obj2.semedian, color='crimson', lw=1.5)
