@@ -30,8 +30,8 @@ from numpy import array
 from scipy import inf
 from scipy.stats import poisson
 
+import spacepy
 import spacepy.toolbox as tb
-import spacepy.time as st
 import spacepy.lib
 
 #Py3k compatibility renamings
@@ -94,12 +94,19 @@ class PickleAssembleTests(unittest.TestCase):
     def testSaveLoadPickleCompress(self):
         """savePickle should write a pickle to disk and loadPickle should load it (compressed)"""
         tb.savepickle(os.path.join(self.tempdir, 'test_pickle_1.pkl'), self.D1, compress=True)
-        files = glob.glob(os.path.join(self.tempdir, '*.pkl.gz'))
-        self.assertTrue(os.path.join(self.tempdir,'test_pickle_1.pkl.gz') in files)
+        files = os.listdir(self.tempdir)
+        self.assertTrue('test_pickle_1.pkl.gz' in files)
+        self.assertFalse('test_pickle_1.pkl' in files)
         DD = tb.loadpickle(os.path.join(self.tempdir,'test_pickle_1.pkl'))
         self.assertEqual(self.D1, DD)
         DD = tb.loadpickle(os.path.join(self.tempdir,'test_pickle_1.pkl.gz'))
         self.assertEqual(self.D1, DD)
+        # Save without specifying compression, make sure saves compressed
+        # (because compressed file already exists)
+        tb.savepickle(os.path.join(self.tempdir, 'test_pickle_1.pkl'), self.D1)
+        files = os.listdir(self.tempdir)
+        self.assertTrue('test_pickle_1.pkl.gz' in files)
+        self.assertFalse('test_pickle_1.pkl' in files)
 
     def test_assemble(self):
         tb.savepickle(os.path.join(self.tempdir, 'test_pickle_1.pkl'), self.D1)
@@ -113,16 +120,78 @@ class PickleAssembleTests(unittest.TestCase):
 
 
 class SimpleFunctionTests(unittest.TestCase):
-    def test_quaternionNormalize(self):
-        """quaternionNormalize should have known results"""
-        tst = tb.quaternionNormalize([0.707, 0, 0.707, 0.2])
-        ans = [ 0.69337122,  0.        ,  0.69337122,  0.19614462]
-        numpy.testing.assert_array_almost_equal(ans, tst)
+
+    def test_humansort(self):
+        """human_sort should give known answers"""
+        dat = ['1.10', '1.2', '1.3', '1.20']
+        self.assertEqual(
+            ['1.2', '1.3', '1.10', '1.20'],
+            tb.human_sort(dat))
+        dat = ['r1.txt', 'r10.txt', 'r2.txt']
+        dat.sort() # Standard Python sort
+        self.assertEqual(['r1.txt', 'r10.txt', 'r2.txt'], dat)
+        self.assertEqual(['r1.txt', 'r2.txt', 'r10.txt'],
+                         tb.human_sort(dat))
+        dat = [5, 1, 3, -1]
+        self.assertEqual([-1, 1, 3, 5], tb.human_sort(dat))
+
+    def test_quaternionDeprecation(self):
+        """Make sure deprecated quaternion functions work"""
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always', category=DeprecationWarning)
+            tst = tb.quaternionNormalize([0.707, 0, 0.707, 0.2])
+        self.assertEqual(1, len(w))
+        self.assertEqual(DeprecationWarning, w[0].category)
+        self.assertEqual(
+            'moved to spacepy.coordinates',
+            str(w[0].message))
+        numpy.testing.assert_array_almost_equal(
+            [0.693,  0.,  0.693,  0.196], tst, decimal=2)
+
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always', category=DeprecationWarning)
+            tst = tb.quaternionRotateVector([0.7071, 0, 0, 0.7071],
+                                            [0, 1, 0])
+        self.assertEqual(1, len(w))
+        self.assertEqual(DeprecationWarning, w[0].category)
+        self.assertEqual(
+            'moved to spacepy.coordinates',
+            str(w[0].message))
+        numpy.testing.assert_array_almost_equal(
+            [0, 0, 1], tst, decimal=5)
+
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always', category=DeprecationWarning)
+            tst = tb.quaternionMultiply([1., 0, 0, 0],
+                                        [0., 0, 0, 1], scalarPos='first')
+        self.assertEqual(1, len(w))
+        self.assertEqual(DeprecationWarning, w[0].category)
+        self.assertEqual(
+            'moved to spacepy.coordinates',
+            str(w[0].message))
+        numpy.testing.assert_array_equal([0, 0, 0, 1], tst)
+
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always', category=DeprecationWarning)
+            tst = tb.quaternionConjugate([.707, 0, .707, 0.2])
+        self.assertEqual(1, len(w))
+        self.assertEqual(DeprecationWarning, w[0].category)
+        self.assertEqual(
+            'moved to spacepy.coordinates',
+            str(w[0].message))
+        numpy.testing.assert_array_equal([-.707, 0, -.707, 0.2], tst)
 
     def test_indsFromXrange(self):
         """indsFromXrange should have known result"""
         foo = xrange(23, 39)
         self.assertEqual([23, 39], tb.indsFromXrange(foo))
+        foo = xrange(5)
+        self.assertEqual([0, 5], tb.indsFromXrange(foo))
+
+    def test_indsFromXrange_zerolen(self):
+        """indsFromXrange with zero length range"""
+        foo = xrange(20, 20)  # empty
+        self.assertEqual([20, 20], tb.indsFromXrange(foo))
 
     def test_interweave(self):
         """interweave should have known result"""
@@ -163,11 +232,34 @@ class SimpleFunctionTests(unittest.TestCase):
         output = StringIO.StringIO()
         sys.stdout = output
         self.assertEqual(tb.progressbar(0, 1, 100), None)
+        self.assertEqual(tb.progressbar(100, 1, 100), None)
         result = output.getvalue()
         output.close()
-        self.assertEqual(result, "\rDownload Progress ...0%")
+        self.assertEqual(result, "\rDownload Progress ...0%"
+                         "\rDownload Progress ...100%\n")
         sys.stdout = realstdout
 
+    def test_progressbar_bigblock(self):
+        """progressbar should not go over 100% with big blocks"""
+        realstdout = sys.stdout
+        output = StringIO.StringIO()
+        sys.stdout = output
+        try:
+            for i in range(4):
+                self.assertEqual(tb.progressbar(i, 100, 205), None)
+            result = output.getvalue()
+        finally:
+            sys.stdout = realstdout
+            output.close()
+        self.assertEqual(
+            result,
+            "\rDownload Progress ...0%"
+            "\rDownload Progress ...49%"
+            "\rDownload Progress ...98%"
+            "\rDownload Progress ...100%"
+            "\n"
+        )
+
     def test_query_yes_no(self):
         '''query_yes_no should return known strings for known input'''
         realstdout = sys.stdout
@@ -281,19 +373,31 @@ class SimpleFunctionTests(unittest.TestCase):
         """feq should return true when they are equal"""
         val1 = 1.1234
         val2 = 1.1235
-        self.assertTrue(tb.feq(val1, val2, 0.0001))
-        numpy.testing.assert_array_equal(
-            [False, True, False, False],
-            tb.feq([1., 2., 3., 4.],
-                   [1.25, 2.05, 2.2, 500.1],
-                   0.1)
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always', category=DeprecationWarning)
+            self.assertTrue(tb.feq(val1, val2, 0.0001))
+            numpy.testing.assert_array_equal(
+                [False, True, False, False],
+                tb.feq([1., 2., 3., 4.],
+                       [1.25, 2.05, 2.2, 500.1],
+                       0.1)
             )
+        self.assertEqual(2, len(w))
+        for this_w in w:
+            self.assertEqual(DeprecationWarning, this_w.category)
+            self.assertEqual(DeprecationWarning, this_w.category)
+            self.assertEqual('use numpy.isclose', str(this_w.message))
 
     def testfeq_notequal(self):
         """feq should return false when they are not equal"""
         val1 = 1.1234
         val2 = 1.1235
-        self.assertFalse(tb.feq(val1, val2, 0.000005))
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always', category=DeprecationWarning)
+            self.assertFalse(tb.feq(val1, val2, 0.000005))
+        self.assertEqual(1, len(w))
+        self.assertEqual(DeprecationWarning, w[0].category)
+        self.assertEqual('use numpy.isclose', str(w[0].message))
 
     def test_medAbsDev(self):
         """medAbsDev should return a known range for given random input"""
@@ -348,12 +452,13 @@ class SimpleFunctionTests(unittest.TestCase):
         numpy.testing.assert_equal(
             [  7,  45, 149, 283, 272, 162,  71,   9,   0,   2], sample)
         #This is a very coarse chunk-check to allow for variations in
-        #RNGs. Values from 100000 iterations
+        #RNGs; by using the same seed it should be deterministic on a
+        #given RNG. Values from 100000 iterations
         numpy.testing.assert_allclose(
-            [3.,  34., 131., 260., 249., 143.,  58.,   4.,   0.,   0.],
+            [3.,  35., 131., 260., 249., 143.,  58.,   4.,   0.,   0.],
             ci_low, atol=2, rtol=1e-2)
         numpy.testing.assert_allclose(
-            [12.,  56., 168., 306., 295., 181.,  84.,  14.,   0.,   5.],
+            [12.,  56., 168., 307., 295., 181.,  85.,  14.,   0.,   5.],
             ci_high, atol=2, rtol=1e-2)
 
     def test_logspace(self):
@@ -421,6 +526,21 @@ class SimpleFunctionTests(unittest.TestCase):
             self.assertEqual(val, tb.pmm(data[i]))
         self.assertEqual([[1, 6], [5, 24], [6.0, 67.340000000000003]], tb.pmm(*data) )
 
+    def test_pmm_object(self):
+        """Test pmm handling of object arrays"""
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always')
+            data = [array([5,9,23,24,6]).astype(object),
+                    [datetime.datetime(2000, 3, 1, 0, 1), datetime.datetime(2000, 2, 28), datetime.datetime(2000, 3, 1)],
+                    numpy.array(['foo', 'bar', 'baz'], dtype=object),
+                    ]
+            real_ans = [[[5, 24]],
+                        [[datetime.datetime(2000, 2, 28), datetime.datetime(2000, 3, 1, 0, 1)]],
+                        [['bar', 'foo']],
+            ]
+            for i, val in enumerate(real_ans):
+                self.assertEqual(val, tb.pmm(data[i]))
+
     def test_rad2mlt(self):
         """rad2mlt should give known answers (regression)"""
         real_ans = array([ -6.        ,  -4.10526316,  -2.21052632,  -0.31578947,
@@ -510,7 +630,7 @@ class SimpleFunctionTests(unittest.TestCase):
             numpy.testing.assert_almost_equal(outputs[i], tb.bin_edges_to_center(val))
 
     def test_hypot(self):
-        """hypot should have known output"""
+        """hypot should have known output, call Python or C (as default)"""
         invals = [ [3, 4], list(range(3, 6)), list(range(3,10)), [-1,2,3] ]
         ans = [ 5, 7.0710678118654755, 16.73320053068151, 3.7416573867739413 ]
         for i, tst in enumerate(invals):
@@ -518,9 +638,33 @@ class SimpleFunctionTests(unittest.TestCase):
         for i, tst in enumerate(invals):
             self.assertAlmostEqual(ans[i], tb.hypot(tst))
         self.assertEqual(5.0, tb.hypot(5.0))
-        if spacepy.lib.have_libspacepy:
-            self.assertEqual(tb.hypot(numpy.array([3.,4.])), 5.0)
-            self.assertEqual(tb.hypot(numpy.array([3,4])), 5.0)
+        # Same as first set of inputs but explicitly np arrays
+        invals = [numpy.asarray([3, 4]), numpy.array([3., 4.]),
+                  numpy.arange(3, 6), numpy.arange(3, 10),
+                  numpy.asarray([-1, 2, 3])]
+        ans = [5, 5.,
+               7.0710678118654755, 16.73320053068151,
+               3.7416573867739413]
+        for i, tst in enumerate(invals):
+            self.assertAlmostEqual(ans[i], tb.hypot(*tst))
+        for i, tst in enumerate(invals):
+            self.assertAlmostEqual(ans[i], tb.hypot(tst))
+        # Few tests of array subclasses
+        invals = [spacepy.dmarray([3, 4]), spacepy.dmarray([3., 4.]),
+                  spacepy.dmarray([-1, 2, 3])]
+        ans = [5, 5.,
+               3.7416573867739413]
+        for i, tst in enumerate(invals):
+            self.assertAlmostEqual(ans[i], tb.hypot(*tst))
+
+    @unittest.skipUnless(spacepy.lib.have_libspacepy, 'libspacepy not found')
+    def test_hypot_python(self):
+        """Explicitly call Python version of hypot if had C before"""
+        try:
+            spacepy.lib.have_libspacepy = False
+            self.test_hypot() # Repeat tests without the C code
+        finally:
+            spacepy.lib.have_libspacepy = True
 
     def testThreadJob(self):
         """Multithread the square of an array"""
@@ -654,7 +798,28 @@ class SimpleFunctionTests(unittest.TestCase):
         res = tb.poisson_fit(data)
         self.assertEqual(ans, numpy.round(res.x))
 
-            
+    def test_assemble_qindenton_daily(self):
+        """Assemble OMNI data structure from Qin-Denton daily files"""
+        dailydir = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)),
+            'data', 'qindenton_daily')
+        omnidata = tb._assemble_qindenton_daily(dailydir)
+        self.assertEqual(
+            ['ByIMF', 'Bz1', 'Bz2', 'Bz3', 'Bz4', 'Bz5', 'Bz6', 'BzIMF',
+             'DOY', 'Dst', 'G1', 'G2', 'G3', 'Kp', 'Pdyn', 'Qbits',
+             'RDT', 'UTC', 'W1', 'W2', 'W3', 'W4', 'W5', 'W6', 'akp3',
+             'dens', 'velo'],
+            sorted(omnidata.keys()))
+        numpy.testing.assert_array_equal(
+            [14,  16,  18,  17,  17,  12,  10,  11,  11,   4,   0,  -8, -13,
+             -13, -12, -11,  -9,  -5,   2,   6,   9,   9,  10,   6,  -2,  -8,
+             -11, -11, -12, -20, -27, -29, -26, -22, -17, -22, -25, -29, -33,
+             -36, -41, -47, -47, -39, -35, -41, -42, -45],
+            omnidata['Dst'])
+        numpy.testing.assert_array_equal(
+            2, omnidata['Qbits']['W6'])
+
+
 class TBTimeFunctionTests(unittest.TestCase):
     def setUp(self):
         super(TBTimeFunctionTests, self).setUp()
